@@ -19,7 +19,7 @@ def save_data(FNumber,FName,FCOUNTRY):
     return myitem
 
 
-def save_api(FNumber,FName,FCOUNTRY):
+def save_api(FNumber,FName,FCOUNTRY,X_KDApi_AcctID,X_KDApi_UserName,X_KDApi_AppID,X_KDApi_AppSec,X_KDApi_ServerUrl):
     # !/usr/bin/python
     # -*- coding:UTF-8 -*-
     # 首先构造一个SDK实例
@@ -35,8 +35,8 @@ def save_api(FNumber,FName,FCOUNTRY):
     # 初始化方案二（新增）：InitConfig初始化方法，直接传参，不使用配置文件
     # acct_id:第三方系统登录授权的账套ID,user_name:第三方系统登录授权的用户,app_id:第三方系统登录授权的应用ID,app_sec:第三方系统登录授权的应用密钥
     # server_url:k3cloud环境url(仅私有云环境需要传递),lcid:账套语系(默认2052),org_num:组织编码(启用多组织时配置对应的组织编码才有效)
-    api_sdk.InitConfig('62f49d037697ee', '许雯琪', '232256_3f1r48FtTMmW4W9sWf3C0z0K7rQXWqNv',
-                       '322353d1dfc844a086d8376cc6f70bf6', 'http://cellprobio.gnway.cc/k3cloud')
+    api_sdk.InitConfig(X_KDApi_AcctID,X_KDApi_UserName, X_KDApi_AppID,
+                       X_KDApi_AppSec, X_KDApi_ServerUrl)
 
     # 此处仅构造保存接口的部分字段数据示例，使用时请参考WebAPI具体接口的实际参数列表
     current_time = time.strftime('%Y%m%d%H%M%S', time.localtime())
